@@ -111,8 +111,6 @@ class Pywedge_Charts():
             display(g)
             h = widgets.HBox([three, four])
             display(h)
-            footer = widgets.HTML(value="<p><em>Charts compiled by Pywedge make_charts </em></p>")
-            display(footer)
             
         with out2:
             header = widgets.HTML(value="<h1>Pie Charts </h1>")
@@ -170,7 +168,7 @@ class Pywedge_Charts():
                           Color=list(train_mc.select_dtypes(exclude='number').columns)):
                 
                 fig2 = px.violin(train_mc, X_Axis, Y_Axis, Color, box=True, hover_data=train_mc.columns)
-                fig2.update_layout(title=f'{X_Axis.title()}', 
+                fig2.update_layout(title=f'{X_Axis.title()} vs {Y_Axis.title()}', 
                                 xaxis_title=f'{X_Axis.title()}',
                                 autosize=False,width=600,height=600)
                 fig2.show()
@@ -221,7 +219,7 @@ class Pywedge_Charts():
                           Color=list(train_mc.select_dtypes(exclude='number').columns)):
                 
                 fig2 = px.histogram(train_mc, X_Axis, Y_Axis, Color, marginal='violin', hover_data=train_mc.columns)
-                fig2.update_layout(title=f'{X_Axis.title()}', 
+                fig2.update_layout(title=f'{X_Axis.title()} vs {Y_Axis.title()}', 
                                 xaxis_title=f'{X_Axis.title()}',
                                 autosize=False,width=600,height=600)
                 fig2.show()
